@@ -16,27 +16,35 @@ sudo DEBIAN_FRONTEND=noninteractive apt-get install -y \
 
 sudo DEBIAN_FRONTEND=noninteractive apt-get install -y \
   wget unzip cmake g++ pkg-config g++-mingw-w64-x86-64 nsis \
-  docbook-xsl xsltproc gettext po4a imagemagick zip libz-mingw-w64-dev \
-  wine32 winbind
+  docbook-xsl xsltproc gettext po4a imagemagick zip \
+  wine32 winbind pipx
+
+if ! command -v msys2dl &> /dev/null; then
+  # Install a tool to download pre-compiled libraries from msys2 repositories
+  sudo PIPX_HOME=/opt/pipx PIPX_BIN_DIR=/usr/local/bin \
+    pipx install msys2dl==2.1.1
+fi
+
+if ! command -v cygpath &> /dev/null; then
+  # Install the script that does nothing useful but is required by wx-config from MSYS2
+  sudo mkdir -p /usr/local/bin
+  sudo cp "$BASE_DIR"/cygpath /usr/local/bin/cygpath
+fi
 
 mkdir -p deb
 pushd deb
 
-wget \
-  https://github.com/GrandOrgue/Mingw64LibGnuRx/releases/download/2.6.1-1.os/libgnurx-mingw-w64_2.6.1-1.os_all.deb \
-  https://launchpad.net/~tobydox/+archive/ubuntu/mingw-w64/+files/fftw-mingw-w64_3.3.6-3_all.deb \
-  https://github.com/GrandOrgue/JackCross/releases/download/1.9.19-1.os/jack-mingw-w64_1.9.19-1.os_all.deb \
-  https://github.com/GrandOrgue/WavPackCross/releases/download/5.4.0-1.go/wavpack-mingw-w64_5.4.0-1.go_all.deb \
-  https://github.com/GrandOrgue/WxWidgetsCross/releases/download/3.2.3-1.go/wxwidgets3-mingw-w64_3.2.3-1.go_all.deb \
-  https://github.com/GrandOrgue/YamlCppAdd/releases/download/0.6.2-6.go/libyaml-cpp-mingw-w64_0.6.2-6.go_all.deb
-
-sudo apt-get install -y \
-  ./libgnurx-mingw-w64_2.6.1-1.os_all.deb \
-  ./fftw-mingw-w64_3.3.6-3_all.deb \
-  ./jack-mingw-w64_1.9.19-1.os_all.deb \
-  ./wavpack-mingw-w64_5.4.0-1.go_all.deb \
-  ./wxwidgets3-mingw-w64_3.2.3-1.go_all.deb \
-  ./libyaml-cpp-mingw-w64_0.6.2-6.go_all.deb
+# MSYS2 packages are built against newer libstdc++.
+# It will be downloaded as a dependency for the packages below.
+PACKAGES_FROM_MSYS2=(curl-winssl fftw jack2 wavpack yaml-cpp wxwidgets3.2-msw)
+DEB_PACKAGES_FROM_MSYS2=("${PACKAGES_FROM_MSYS2[@]/%/-msys2-mingw64}")
+if ! dpkg -l "${DEB_PACKAGES_FROM_MSYS2[@]}" &>/dev/null; then
+  # Download packages from MSYS2 repositories and convert them to .deb.
+  rm -rf ./msys2
+  mkdir msys2
+  msys2dl make-deb --output ./msys2 --env mingw64 -- "${PACKAGES_FROM_MSYS2[@]}"
+  sudo dpkg -i msys2/*.deb
+fi
 
 popd
 
