@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2024 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -52,7 +52,7 @@ public:
   const std::vector<wxString> &GetDependencies() const;
   const std::vector<wxString> &GetDependencyTitles() const;
 
-  bool IsUsable(const GOOrganList &organs) const;
+  bool IsUsable() const;
   bool IsComplete(const GOOrganList &organs) const;
 };
 
