@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2024 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -11,8 +11,9 @@
 #include <wx/intl.h>
 #include <wx/log.h>
 
+#include "GOBool3.h"
+#include "GOConfigReaderDB.h"
 #include "GOUtil.h"
-#include "config/GOConfigReaderDB.h"
 
 GOConfigReader::GOConfigReader(
   GOConfigReaderDB &cfg, bool strict, bool hw1Check)
@@ -20,8 +21,8 @@ GOConfigReader::GOConfigReader(
 
 bool GOConfigReader::Read(
   GOSettingType type,
-  wxString group,
-  wxString key,
+  const wxString &group,
+  const wxString &key,
   bool required,
   wxString &value) {
   bool found = false;
@@ -63,10 +64,10 @@ bool GOConfigReader::Read(
 
 wxString GOConfigReader::ReadString(
   GOSettingType type,
-  wxString group,
-  wxString key,
+  const wxString &group,
+  const wxString &key,
   bool required,
-  wxString defaultValue) {
+  const wxString &defaultValue) {
   wxString value;
   bool found = Read(type, group, key, required, value);
 
@@ -76,16 +77,19 @@ wxString GOConfigReader::ReadString(
 }
 
 wxString GOConfigReader::ReadString(
-  GOSettingType type, wxString group, wxString key, bool required) {
+  GOSettingType type,
+  const wxString &group,
+  const wxString &key,
+  bool required) {
   return ReadString(type, group, key, required, wxT(""));
 }
 
 wxString GOConfigReader::ReadStringTrim(
   GOSettingType type,
-  wxString group,
-  wxString key,
+  const wxString &group,
+  const wxString &key,
   bool required,
-  wxString defaultValue) {
+  const wxString &defaultValue) {
   wxString value = ReadString(type, group, key, required, defaultValue);
 
   if (value.length() > 0 && value[value.length() - 1] == ' ') {
@@ -101,16 +105,19 @@ wxString GOConfigReader::ReadStringTrim(
 }
 
 wxString GOConfigReader::ReadStringTrim(
-  GOSettingType type, wxString group, wxString key, bool required) {
+  GOSettingType type,
+  const wxString &group,
+  const wxString &key,
+  bool required) {
   return ReadStringTrim(type, group, key, required, wxT(""));
 }
 
 wxString GOConfigReader::ReadStringNotEmpty(
   GOSettingType type,
-  wxString group,
-  wxString key,
+  const wxString &group,
+  const wxString &key,
   bool required,
-  wxString defaultValue) {
+  const wxString &defaultValue) {
   wxString value = ReadString(type, group, key, required, defaultValue);
 
   if (value.Trim().length() == 0 && m_Strict) {
@@ -121,12 +128,18 @@ wxString GOConfigReader::ReadStringNotEmpty(
 }
 
 wxString GOConfigReader::ReadStringNotEmpty(
-  GOSettingType type, wxString group, wxString key, bool required) {
+  GOSettingType type,
+  const wxString &group,
+  const wxString &key,
+  bool required) {
   return ReadStringNotEmpty(type, group, key, required, wxT(""));
 }
 
 wxString GOConfigReader::ReadFileName(
-  GOSettingType type, wxString group, wxString key, bool required) {
+  GOSettingType type,
+  const wxString &group,
+  const wxString &key,
+  bool required) {
   const wxString fileName = ReadStringTrim(type, group, key, required);
 
   if (m_IsHw1Check && fileName.Find(wxT('/')) != wxNOT_FOUND) {
@@ -137,11 +150,14 @@ wxString GOConfigReader::ReadFileName(
 }
 
 bool GOConfigReader::ReadBoolean(
-  GOSettingType type, wxString group, wxString key, bool required) {
+  GOSettingType type,
+  const wxString &group,
+  const wxString &key,
+  bool required) {
   return ReadBoolean(type, group, key, required, false);
 }
 
-int GOConfigReader::ReadBooleanTriple(
+GOBool3 GOConfigReader::ReadBooleanTriple(
   GOSettingType type,
   const wxString &group,
   const wxString &key,
@@ -149,7 +165,7 @@ int GOConfigReader::ReadBooleanTriple(
   wxString value;
 
   if (!Read(type, group, key, required, value))
-    return -1;
+    return BOOL3_DEFAULT;
 
   if (value.length() > 0 && value[value.length() - 1] == ' ') {
     if (m_Strict)
@@ -161,9 +177,9 @@ int GOConfigReader::ReadBooleanTriple(
     value.Trim();
   }
   if (value == wxT("Y") || value == wxT("y"))
-    return 1;
+    return BOOL3_TRUE;
   if (value == wxT("N") || value == wxT("n"))
-    return 0;
+    return BOOL3_FALSE;
   value.MakeUpper();
   wxLogWarning(
     _("Strange boolean value for section '%s' entry '%s': %s"),
@@ -171,9 +187,9 @@ int GOConfigReader::ReadBooleanTriple(
     key.c_str(),
     value.c_str());
   if (value.Length() && value[0] == wxT('Y'))
-    return 1;
+    return BOOL3_TRUE;
   else if (value.Length() && value[0] == wxT('N'))
-    return 0;
+    return BOOL3_FALSE;
 
   wxString error;
   error.Printf(
@@ -186,17 +202,18 @@ int GOConfigReader::ReadBooleanTriple(
 
 bool GOConfigReader::ReadBoolean(
   GOSettingType type,
-  wxString group,
-  wxString key,
+  const wxString &group,
+  const wxString &key,
   bool required,
   bool defaultValue) {
-  int tripleValue = ReadBooleanTriple(type, group, key, required);
-
-  return tripleValue < 0 ? defaultValue : (tripleValue);
+  return to_bool(ReadBooleanTriple(type, group, key, required), defaultValue);
 }
 
 GOLogicalColour GOConfigReader::ReadColor(
-  GOSettingType type, wxString group, wxString key, bool required) {
+  GOSettingType type,
+  const wxString &group,
+  const wxString &key,
+  bool required) {
   return ReadColor(type, group, key, required, wxT("BLACK"));
 }
 
@@ -253,10 +270,10 @@ bool parseColor(GOLogicalColour &result, wxString value) {
 
 GOLogicalColour GOConfigReader::ReadColor(
   GOSettingType type,
-  wxString group,
-  wxString key,
+  const wxString &group,
+  const wxString &key,
   bool required,
-  wxString defaultValue) {
+  const wxString &defaultValue) {
   wxString value;
   if (!Read(type, group, key, required, value))
     value = defaultValue;
@@ -322,8 +339,8 @@ GOLogicalColour GOConfigReader::ReadColor(
 
 int GOConfigReader::ReadInteger(
   GOSettingType type,
-  wxString group,
-  wxString key,
+  const wxString &group,
+  const wxString &key,
   int nmin,
   int nmax,
   bool required) {
@@ -332,8 +349,8 @@ int GOConfigReader::ReadInteger(
 
 int GOConfigReader::ReadInteger(
   GOSettingType type,
-  wxString group,
-  wxString key,
+  const wxString &group,
+  const wxString &key,
   int nmin,
   int nmax,
   bool required,
@@ -374,22 +391,28 @@ int GOConfigReader::ReadInteger(
       value.c_str());
   }
 
-  if (nmin <= retval && retval <= nmax)
-    return retval;
-
-  wxString error;
-  error.Printf(
-    _("Out of range value at section '%s' entry '%s': %ld"),
-    group,
-    key,
-    retval);
-  throw error;
+  if (retval < nmin || retval > nmax) {
+    if (type == ODFSetting)
+      throw wxString::Format(
+        _("Out of range value at section '%s' entry '%s': %ld"),
+        group,
+        key,
+        retval);
+    wxLogError(
+      _("Out of range value at section '%s' entry '%s': %ld. Assumed %d"),
+      group,
+      key,
+      retval,
+      defaultValue);
+    retval = defaultValue;
+  }
+  return retval;
 }
 
 int GOConfigReader::ReadLong(
   GOSettingType type,
-  wxString group,
-  wxString key,
+  const wxString &group,
+  const wxString &key,
   int nmin,
   int nmax,
   bool required) {
@@ -398,8 +421,8 @@ int GOConfigReader::ReadLong(
 
 int GOConfigReader::ReadLong(
   GOSettingType type,
-  wxString group,
-  wxString key,
+  const wxString &group,
+  const wxString &key,
   int nmin,
   int nmax,
   bool required,
@@ -409,8 +432,8 @@ int GOConfigReader::ReadLong(
 
 double GOConfigReader::ReadFloat(
   GOSettingType type,
-  wxString group,
-  wxString key,
+  const wxString &group,
+  const wxString &key,
   double nmin,
   double nmax,
   bool required) {
@@ -419,8 +442,8 @@ double GOConfigReader::ReadFloat(
 
 double GOConfigReader::ReadFloat(
   GOSettingType type,
-  wxString group,
-  wxString key,
+  const wxString &group,
+  const wxString &key,
   double nmin,
   double nmax,
   bool required,
@@ -455,22 +478,28 @@ double GOConfigReader::ReadFloat(
     throw error;
   }
 
-  if (nmin <= retval && retval <= nmax)
-    return retval;
-
-  wxString error;
-  error.Printf(
-    _("Out of range value at section '%s' entry '%s': %f"),
-    group.c_str(),
-    key.c_str(),
-    retval);
-  throw error;
+  if (retval < nmin || retval > nmax) {
+    if (type == ODFSetting)
+      throw wxString::Format(
+        _("Out of range value at section '%s' entry '%s': %f"),
+        group,
+        key,
+        retval);
+    wxLogError(
+      _("Out of range value at section '%s' entry '%s': %f. Assumed %f."),
+      group,
+      key,
+      retval,
+      defaultValue);
+    retval = defaultValue;
+  }
+  return retval;
 }
 
 unsigned GOConfigReader::ReadSize(
   GOSettingType type,
-  wxString group,
-  wxString key,
+  const wxString &group,
+  const wxString &key,
   unsigned size_type,
   bool required) {
   return ReadSize(type, group, key, size_type, required, wxT("SMALL"));
@@ -478,11 +507,11 @@ unsigned GOConfigReader::ReadSize(
 
 unsigned GOConfigReader::ReadSize(
   GOSettingType type,
-  wxString group,
-  wxString key,
+  const wxString &group,
+  const wxString &key,
   unsigned size_type,
   bool required,
-  wxString defaultValue) {
+  const wxString &defaultValue) {
   static const int sizes[2][4]
     = {{800, 1007, 1263, 1583}, {500, 663, 855, 1095}};
   wxString value;
@@ -512,7 +541,7 @@ unsigned GOConfigReader::ReadSize(
 
   long size;
   if (parseLong(size, value))
-    if (100 <= size && size <= 4000)
+    if (100 <= size && size <= 32000)
       return size;
 
   wxString error;
@@ -525,16 +554,19 @@ unsigned GOConfigReader::ReadSize(
 }
 
 unsigned GOConfigReader::ReadFontSize(
-  GOSettingType type, wxString group, wxString key, bool required) {
+  GOSettingType type,
+  const wxString &group,
+  const wxString &key,
+  bool required) {
   return ReadFontSize(type, group, key, required, wxT("NORMAL"));
 }
 
 unsigned GOConfigReader::ReadFontSize(
   GOSettingType type,
-  wxString group,
-  wxString key,
+  const wxString &group,
+  const wxString &key,
   bool required,
-  wxString defaultValue) {
+  const wxString &defaultValue) {
   wxString value;
   if (!Read(type, group, key, required, value))
     value = defaultValue;
@@ -573,8 +605,8 @@ unsigned GOConfigReader::ReadFontSize(
 
 int GOConfigReader::ReadEnum(
   GOSettingType type,
-  wxString group,
-  wxString key,
+  const wxString &group,
+  const wxString &key,
   const struct IniFileEnumEntry *entry,
   unsigned count,
   bool required,
@@ -616,8 +648,8 @@ int GOConfigReader::ReadEnum(
 
 int GOConfigReader::ReadEnum(
   GOSettingType type,
-  wxString group,
-  wxString key,
+  const wxString &group,
+  const wxString &key,
   const struct IniFileEnumEntry *entry,
   unsigned count,
   bool required) {
