@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2024 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -13,6 +13,7 @@
 #include <wx/hashmap.h>
 #include <wx/string.h>
 
+#include "GOBool3.h"
 #include "GOLogicalColour.h"
 
 class GOConfigReaderDB;
@@ -35,8 +36,8 @@ private:
 
   bool Read(
     GOSettingType type,
-    wxString group,
-    wxString key,
+    const wxString &group,
+    const wxString &key,
     bool required,
     wxString &value);
 
@@ -47,130 +48,159 @@ public:
   /**
    * Reads a triple-value boolean (-1 - not defined, 0 - false, 1 - true)
    */
-  int ReadBooleanTriple(
+  GOBool3 ReadBooleanTriple(
     GOSettingType type,
     const wxString &group,
     const wxString &key,
     bool required);
   bool ReadBoolean(
-    GOSettingType type, wxString group, wxString key, bool required = true);
+    GOSettingType type,
+    const wxString &group,
+    const wxString &key,
+    bool required = true);
   bool ReadBoolean(
     GOSettingType type,
-    wxString group,
-    wxString key,
+    const wxString &group,
+    const wxString &key,
     bool required,
     bool defaultValue);
   GOLogicalColour ReadColor(
-    GOSettingType type, wxString group, wxString key, bool required = true);
+    GOSettingType type,
+    const wxString &group,
+    const wxString &key,
+    bool required = true);
   GOLogicalColour ReadColor(
     GOSettingType type,
-    wxString group,
-    wxString key,
+    const wxString &group,
+    const wxString &key,
     bool required,
-    wxString defaultValue);
-  wxString ReadString(
-    GOSettingType type, wxString group, wxString key, bool required = true);
+    const wxString &defaultValue);
   wxString ReadString(
     GOSettingType type,
-    wxString group,
-    wxString key,
+    const wxString &group,
+    const wxString &key,
+    bool required = true);
+  wxString ReadString(
+    GOSettingType type,
+    const wxString &group,
+    const wxString &key,
     bool required,
-    wxString defaultValue);
-  wxString ReadStringTrim(
-    GOSettingType type, wxString group, wxString key, bool required = true);
+    const wxString &defaultValue);
   wxString ReadStringTrim(
     GOSettingType type,
-    wxString group,
-    wxString key,
+    const wxString &group,
+    const wxString &key,
+    bool required = true);
+  wxString ReadStringTrim(
+    GOSettingType type,
+    const wxString &group,
+    const wxString &key,
     bool required,
-    wxString defaultValue);
-  wxString ReadStringNotEmpty(
-    GOSettingType type, wxString group, wxString key, bool required = true);
+    const wxString &defaultValue);
   wxString ReadStringNotEmpty(
     GOSettingType type,
-    wxString group,
-    wxString key,
+    const wxString &group,
+    const wxString &key,
+    bool required = true);
+  wxString ReadStringNotEmpty(
+    GOSettingType type,
+    const wxString &group,
+    const wxString &key,
     bool required,
-    wxString defaultValue);
+    const wxString &defaultValue);
   wxString ReadFileName(
-    GOSettingType type, wxString group, wxString key, bool required = true);
+    GOSettingType type,
+    const wxString &group,
+    const wxString &key,
+    bool required = true);
   int ReadInteger(
     GOSettingType type,
-    wxString group,
-    wxString key,
+    const wxString &group,
+    const wxString &key,
     int nmin = 0,
     int nmax = 0,
     bool required = true);
   int ReadInteger(
     GOSettingType type,
-    wxString group,
-    wxString key,
+    const wxString &group,
+    const wxString &key,
     int nmin,
     int nmax,
     bool required,
     int defaultValue);
+  GOBool3 ReadBool3FromInt(
+    GOSettingType type,
+    const wxString &group,
+    const wxString &key,
+    bool required) {
+    return to_bool3(ReadInteger(
+      type, group, key, BOOL3_MIN, BOOL3_MAX, required, BOOL3_DEFAULT));
+  }
   int ReadLong(
     GOSettingType type,
-    wxString group,
-    wxString key,
+    const wxString &group,
+    const wxString &key,
     int nmin = 0,
     int nmax = 0,
     bool required = true);
   int ReadLong(
     GOSettingType type,
-    wxString group,
-    wxString key,
+    const wxString &group,
+    const wxString &key,
     int nmin,
     int nmax,
     bool required,
     int defaultValue);
   double ReadFloat(
     GOSettingType type,
-    wxString group,
-    wxString key,
+    const wxString &group,
+    const wxString &key,
     double nmin = 0,
     double nmax = 0,
     bool required = true);
   double ReadFloat(
     GOSettingType type,
-    wxString group,
-    wxString key,
+    const wxString &group,
+    const wxString &key,
     double nmin,
     double nmax,
     bool required,
     double defaultValue);
   unsigned ReadSize(
     GOSettingType type,
-    wxString group,
-    wxString key,
+    const wxString &group,
+    const wxString &key,
     unsigned size_type = 0,
     bool required = true);
   unsigned ReadSize(
     GOSettingType type,
-    wxString group,
-    wxString key,
+    const wxString &group,
+    const wxString &key,
     unsigned size_type,
     bool required,
-    wxString defaultValue);
-  unsigned ReadFontSize(
-    GOSettingType type, wxString group, wxString key, bool required = true);
+    const wxString &defaultValue);
   unsigned ReadFontSize(
     GOSettingType type,
-    wxString group,
-    wxString key,
+    const wxString &group,
+    const wxString &key,
+    bool required = true);
+  unsigned ReadFontSize(
+    GOSettingType type,
+    const wxString &group,
+    const wxString &key,
     bool required,
-    wxString defaultValue);
+    const wxString &defaultValue);
   int ReadEnum(
     GOSettingType type,
-    wxString group,
-    wxString key,
+    const wxString &group,
+    const wxString &key,
     const struct IniFileEnumEntry *entry,
     unsigned count,
     bool required = true);
   int ReadEnum(
     GOSettingType type,
-    wxString group,
-    wxString key,
+    const wxString &group,
+    const wxString &key,
     const struct IniFileEnumEntry *entry,
     unsigned count,
     bool required,
