@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2024 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -12,14 +12,14 @@
 
 class GOSettingFile : public GOSettingString {
 protected:
-  wxString validate(wxString value);
+  wxString Validate(const wxString &value) const override;
 
 public:
   GOSettingFile(
     GOSettingStore *store,
-    wxString group,
-    wxString name,
-    wxString default_value);
+    const wxString &group,
+    const wxString &name,
+    const wxString &defaultValue);
 };
 
 #endif
