@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2024 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -36,16 +36,16 @@ private:
 
   static const struct GOElementCreator::ButtonDefinitionEntry m_element_types[];
   const struct GOElementCreator::ButtonDefinitionEntry *
-  GetButtonDefinitionList();
+  GetButtonDefinitionList() override;
 
-  void HandleTimer();
+  void HandleTimer() override;
 
   void ButtonStateChanged(int id, bool newState) override;
 
-  void AbortPlayback();
-  void PreparePlayback();
+  void AbortPlayback() override;
+  void PreparePlayback() override;
 
-  void Save(GOConfigWriter &cfg);
+  void Save(GOConfigWriter &cfg) override;
 
   void StartTimer();
   void StopTimer();
@@ -57,10 +57,10 @@ public:
   GOMetronome(GOOrganController *organController);
   virtual ~GOMetronome();
 
-  void Load(GOConfigReader &cfg);
+  void Load(GOConfigReader &cfg) override;
 
-  GOEnclosure *GetEnclosure(const wxString &name, bool is_panel);
-  GOLabelControl *GetLabelControl(const wxString &name, bool is_panel);
+  GOEnclosure *GetEnclosure(const wxString &name, bool is_panel) override;
+  GOLabelControl *GetLabelControl(const wxString &name, bool is_panel) override;
 };
 
 #endif
