@@ -60,7 +60,6 @@ private:
   ptr_vector<GOGeneralCombination> m_framegeneral;
   ptr_vector<GOGeneralCombination> m_general;
   ptr_vector<GOGeneralCombination> m_crescendo;
-  std::vector<GOCombination::ExtraElementsSet> m_CrescendoExtraSets;
   bool m_CrescendoOverrideMode[N_CRESCENDOS];
   GOLabelControl m_CurrFileDisplay;
   GOLabelControl m_PosDisplay;
@@ -68,7 +67,7 @@ private:
   GOLabelControl m_CrescendoDisplay;
   GOLabelControl m_TransposeDisplay;
   GOLabelControl m_NameDisplay;
-  GOEnclosure m_swell;
+  GOEnclosure m_CrescendoCtrl;
 
   // Show the combination file name
   void DisplayCmbFile(const wxString &fileName);
@@ -81,16 +80,30 @@ private:
 
   void SetSetterType(GOSetterState::SetterType type);
   void SetCrescendoType(unsigned no);
+  bool IsCurrentCrescendoOverride() const {
+    return m_CrescendoOverrideMode[m_crescendobank];
+  }
+  wxString GetCrescendoCmbStateName(uint8_t crescendoIdx) const;
   void Crescendo(int pos, bool force = false);
 
   static const struct ButtonDefinitionEntry m_element_types[];
-  const struct ButtonDefinitionEntry *GetButtonDefinitionList();
+  const struct ButtonDefinitionEntry *GetButtonDefinitionList() override;
+
+  /**
+   * Copy the sequencer combination
+   * @param fromIdx - position of the source combination
+   * @param toIdx - position of the destination combination
+   * @param changedBefore - has the combination been changed before. If yes then
+   *   do not check more for changing
+   * @return if any of two combinations is changed or changedBefore
+   */
+  bool CopyFrameGenerals(unsigned fromIdx, unsigned toIdx, bool changedBefore);
 
   void ButtonStateChanged(int id, bool newState) override;
 
   void ControlChanged(GOControl *control) override;
 
-  void PreparePlayback();
+  void PreparePlayback() override;
 
   /**
    * Called after at least one combination is changed
@@ -99,10 +112,13 @@ private:
   void NotifyCmbChanged();
   /**
    * Called after a combination is pushed
-   * When Set is active then marks the cpmbinations as modified
+   * When Set is active then marks the combinations as modified
    * Temporary it calls mOrganController->SetModified()
+   * @param isChanged is the combination actually changed
+   * @param isForceSet is the combination memory changed even the Set button
+   *   is not engaged (for example, Ins or Del are pushed)
    */
-  void NotifyCmbPushed(bool isChanged = true);
+  void NotifyCmbPushed(bool isChanged = true, bool isForceSet = false);
 
   /**
    * Update all setter combination buttons light.
@@ -153,10 +169,10 @@ public:
    */
   void ToYaml(YAML::Node &yamlNode) const override;
   void FromYaml(const YAML::Node &yamlNode) override;
-  void Load(GOConfigReader &cfg);
-  void Save(GOConfigWriter &cfg);
-  GOEnclosure *GetEnclosure(const wxString &name, bool is_panel);
-  GOLabelControl *GetLabelControl(const wxString &name, bool is_panel);
+  void Load(GOConfigReader &cfg) override;
+  void Save(GOConfigWriter &cfg) override;
+  GOEnclosure *GetEnclosure(const wxString &name, bool is_panel) override;
+  GOLabelControl *GetLabelControl(const wxString &name, bool is_panel) override;
 
   /**
    * Called from GOOrganController after loading the initial preset and after
@@ -205,14 +221,6 @@ public:
     unsigned cmbManual,
     GOButtonControl *pButtonToLight) override;
 
-  /*
-   * If current crescendo is in override mode then returns nullptr
-   * If current crescendo is in add mode then fills elementSet and returns a
-   * pointer to it
-   */
-  const GOCombination::ExtraElementsSet *GetCrescendoAddSet(
-    GOCombination::ExtraElementsSet &elementSet);
-
   void Next();
   void Prev();
   void Push();
