@@ -31,4 +31,13 @@ GOGeneralCombination &GOGeneralButtonControl::GetCombination() {
   return m_combination;
 }
 
-wxString GOGeneralButtonControl::GetMidiType() { return _("General"); }
+const wxString WX_MIDI_TYPE_CODE = wxT("General");
+const wxString WX_MIDI_TYPE = _("General");
+
+const wxString &GOGeneralButtonControl::GetMidiTypeCode() const {
+  return WX_MIDI_TYPE_CODE;
+}
+
+const wxString &GOGeneralButtonControl::GetMidiType() const {
+  return WX_MIDI_TYPE;
+}
