@@ -213,28 +213,6 @@ void GOCombination::SetStatesFromYaml(
   }
 }
 
-void GOCombination::GetExtraSetState(
-  GOCombination::ExtraElementsSet &extraSet) {
-  extraSet.clear();
-  // May be called from init a crescendo before init combinations
-  EnsureElementStatesAllocated();
-  for (unsigned i = 0; i < r_ElementDefinitions.size(); i++) {
-    if (
-      m_ElementStates[i] == BOOL3_FALSE
-      && r_ElementDefinitions[i].control->GetCombinationState())
-      extraSet.insert(i);
-  }
-}
-
-void GOCombination::GetEnabledElements(
-  GOCombination::ExtraElementsSet &enabledElements) {
-  enabledElements.clear();
-  for (unsigned i = 0; i < r_ElementDefinitions.size(); i++) {
-    if (to_bool(m_ElementStates[i]))
-      enabledElements.insert(i);
-  }
-}
-
 void GOCombination::EnsureElementStatesAllocated() {
   unsigned defSize = r_ElementDefinitions.size();
 
@@ -438,9 +416,7 @@ bool GOCombination::FillWithCurrent(
   return used;
 }
 
-bool GOCombination::Push(
-  const GOSetterState &setterState,
-  const GOCombination::ExtraElementsSet *extraSet) {
+bool GOCombination::Push(const GOSetterState &setterState) {
   bool used = false;
 
   if (setterState.m_IsActive) {
@@ -451,12 +427,12 @@ bool GOCombination::Push(
   } else {
     EnsureElementStatesAllocated();
     for (unsigned i = 0; i < r_ElementDefinitions.size(); i++) {
-      if (
-        m_ElementStates[i] != BOOL3_DEFAULT
-        && (!extraSet || extraSet->find(i) == extraSet->end())) {
-        r_ElementDefinitions[i].control->SetCombination(
-          to_bool(m_ElementStates[i]));
-        used |= to_bool(m_ElementStates[i]);
+      if (m_ElementStates[i] != BOOL3_DEFAULT) {
+        bool elementState = to_bool(m_ElementStates[i]);
+
+        r_ElementDefinitions[i].control->SetCombinationState(
+          elementState, m_CombinationStateName);
+        used = used || elementState;
       }
     }
   }
