@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2024 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -22,8 +22,8 @@ public:
     GOButtonCallback *callback,
     bool isPushbutton,
     bool isPiston = false);
-  void Push(void);
-  void Set(bool on);
+  void Push(void) override;
+  void SetButtonState(bool on) override;
 
   const wxString &GetMidiTypeCode() const override;
   const wxString &GetMidiType() const override;
