@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -9,11 +9,7 @@
 
 #include "GOCallbackButtonControl.h"
 
-GOElementCreator::GOElementCreator() : m_buttons() {}
-
-GOElementCreator::~GOElementCreator() {}
-
-void GOElementCreator::CreateButtons(GOOrganController *organController) {
+void GOElementCreator::CreateButtons(GOOrganModel &organModel) {
   const struct ButtonDefinitionEntry *entries = GetButtonDefinitionList();
   for (unsigned i = 0;
        entries[i].name != wxEmptyString && entries[i].value >= 0;
@@ -21,7 +17,7 @@ void GOElementCreator::CreateButtons(GOOrganController *organController) {
     if (m_buttons.size() <= (unsigned)entries[i].value)
       m_buttons.resize(entries[i].value + 1);
     m_buttons[entries[i].value] = new GOCallbackButtonControl(
-      organController, this, entries[i].is_pushbutton, entries[i].is_piston);
+      organModel, this, entries[i].is_pushbutton, entries[i].is_piston);
   }
 }
 
@@ -40,8 +36,9 @@ GOButtonControl *GOElementCreator::GetButtonControl(
   return NULL;
 }
 
-void GOElementCreator::ButtonStateChanged(GOButtonControl *button) {
+void GOElementCreator::ButtonStateChanged(
+  GOButtonControl *button, bool newState) {
   for (unsigned i = 0; i < m_buttons.size(); i++)
     if (m_buttons[i] == button)
-      ButtonStateChanged(i);
+      ButtonStateChanged(i, newState);
 }
