@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2024 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -20,13 +20,18 @@
 #include "GOTime.h"
 #include "GOTimerCallback.h"
 
+class GOMidi;
+class GOMidiMap;
 class GOMidiEvent;
 class GOMidiFileReader;
 class GOOrganController;
+class GOTimer;
 
 class GOMidiPlayer : public GOElementCreator, private GOTimerCallback {
 private:
-  GOOrganController *m_OrganController;
+  GOMidiMap &r_MidiMap;
+  GOTimer &r_timer;
+  GOMidi *p_midi;
   GOMidiPlayerContent m_content;
   GOLabelControl m_PlayingTime;
   GOTime m_Start;
@@ -38,18 +43,33 @@ private:
 
   static const struct GOElementCreator::ButtonDefinitionEntry m_element_types[];
   const struct GOElementCreator::ButtonDefinitionEntry *
-  GetButtonDefinitionList();
+  GetButtonDefinitionList() override;
 
   void ButtonStateChanged(int id, bool newState) override;
 
   void UpdateDisplay();
-  void HandleTimer();
+
+  /**
+   * Set the buttons and the display to the initial state
+   */
+  void ResetUI();
+  /**
+   * Send midi event to the organ
+   * @param event the event to process
+   */
+  void PlayMidiEvent(const GOMidiEvent &e);
+  void HandleTimer() override;
 
 public:
   GOMidiPlayer(GOOrganController *organController);
   ~GOMidiPlayer();
 
-  void Clear();
+  /**
+   * Set up for playing any midi
+   * @param pMidi - a pointer to the midi engine
+   */
+  void Setup(GOMidi *pMidi) { p_midi = pMidi; }
+
   void LoadFile(const wxString &filename, unsigned manuals, bool pedal);
   bool IsLoaded();
 
@@ -58,9 +78,14 @@ public:
   void StopPlaying();
   bool IsPlaying();
 
-  void Load(GOConfigReader &cfg);
-  GOEnclosure *GetEnclosure(const wxString &name, bool is_panel);
-  GOLabelControl *GetLabelControl(const wxString &name, bool is_panel);
+  void Load(GOConfigReader &cfg) override;
+  GOEnclosure *GetEnclosure(const wxString &name, bool is_panel) override;
+  GOLabelControl *GetLabelControl(const wxString &name, bool is_panel) override;
+
+  /**
+   * Clean up. Playing will be impossible until Setup is called
+   */
+  void Cleanup();
 };
 
 #endif
