@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2024 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -26,7 +26,8 @@ protected:
 public:
   GOMidiReceiver(GOOrganModel &organModel, GOMidiReceiverType type);
 
-  void Load(GOConfigReader &cfg, const wxString &group, GOMidiMap &map);
+  void Load(
+    GOConfigReader &cfg, const wxString &group, GOMidiMap &map) override;
 
   void SetIndex(int index) { m_Index = index; }
 };
