@@ -51,10 +51,10 @@ private:
   void ChangeKey(int note, unsigned velocity);
   void SetOut(int note, unsigned velocity);
   unsigned GetInternalState(int note);
-  void ChangeState(bool on);
+  void OnDrawstopStateChanged(bool on) override;
   void SetupIsToStoreInCmb() override;
 
-  void PreparePlayback();
+  void PreparePlayback() override;
 
 public:
   GOCoupler(
@@ -75,7 +75,7 @@ public:
     int keyshift,
     int dest_manual,
     GOCouplerType coupler_type);
-  void Load(GOConfigReader &cfg, wxString group);
+  void Load(GOConfigReader &cfg, const wxString &group);
 
   // send key states for all chained couplers
   void RefreshState();
