@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2024 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -8,6 +8,8 @@
 #ifndef GOORGANMODEL_H
 #define GOORGANMODEL_H
 
+#include <set>
+
 #include "ptrvector.h"
 
 #include "combinations/control/GOCombinationButtonSet.h"
@@ -16,6 +18,7 @@
 #include "midi/GOMidiSendProxy.h"
 #include "midi/dialog-creator/GOMidiDialogCreatorProxy.h"
 #include "modification/GOModificationProxy.h"
+#include "pipe-config/GOPipeConfigListener.h"
 #include "pipe-config/GOPipeConfigTreeNode.h"
 
 #include "GOEventHandlerList.h"
@@ -36,7 +39,8 @@ class GOOrganModel : private GOCombinationButtonSet,
                      public GOCombinationControllerProxy,
                      public GOEventHandlerList,
                      public GOMidiDialogCreatorProxy,
-                     public GOMidiSendProxy {
+                     public GOMidiSendProxy,
+                     public GOPipeConfigListener {
 private:
   GOConfig &m_config;
 
@@ -53,6 +57,16 @@ private:
 
   bool m_OrganModelModified;
 
+  /**
+   * Walks across all manuals with divisional coupler engaged and returns the
+   *   set of manuals where the divisional with the same number should be pushed
+   * @param startManual the first manual index where a divisional is pushed
+   * @param manualSet the resulting set of manuals. It always contains
+   *   startManual
+   */
+  void FillCoupledManualsForDivisional(
+    unsigned startManual, std::set<unsigned> &manualSet) const;
+
 protected:
   ptr_vector<GOWindchest> m_windchests;
   ptr_vector<GOManual> m_manuals;
@@ -123,7 +137,7 @@ public:
 
   bool IsOrganModelModified() const { return m_OrganModelModified; }
   void SetOrganModelModified(bool modified);
-  void SetOrganModelModified() { SetOrganModelModified(true); }
+  void NotifyPipeConfigModified() override { SetOrganModelModified(true); }
   void ResetOrganModelModified() { SetOrganModelModified(false); }
 
   void SetModelModificationListener(GOModificationListener *listener) {
@@ -133,9 +147,11 @@ public:
   void UpdateTremulant(GOTremulant *tremulant);
   void UpdateVolume();
 
-  unsigned GetWindchestGroupCount();
+  unsigned GetWindchestCount() const { return m_windchests.size(); }
+  // Returns the windchest number starting with 1
   unsigned AddWindchest(GOWindchest *windchest);
-  GOWindchest *GetWindchest(unsigned index);
+  // Returns the windchest by it's index starting with 0
+  GOWindchest *GetWindchest(unsigned index) { return m_windchests[index]; }
 
   GOEnclosure *GetEnclosureElement(unsigned index);
   unsigned GetEnclosureCount();
@@ -178,6 +194,15 @@ public:
     return m_DivisionalCoupler[index];
   }
 
+  /**
+   * Walks recursively across all manuals with divisional coupler engaged and
+   *   returns a set of manuals where the divisional with the same number should
+   *   be pushed
+   * @param startManual the first manual index where a divisional is pushed
+   * @return the resulting set of manuals. It always contains startManual
+   */
+  std::set<unsigned> GetCoupledManualsForDivisional(unsigned startManual) const;
+
   /**
    * Find a divisional coupler by it's name
    * @param name - the name of the divisional coupler to find
