@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2024 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -41,7 +41,9 @@ public:
   GOPipe(
     GOEventHandlerList *handlerList, GORank *rank, unsigned midi_key_number);
   virtual ~GOPipe();
-  virtual void Load(GOConfigReader &cfg, wxString group, wxString prefix) = 0;
+  virtual void Load(
+    GOConfigReader &cfg, const wxString &group, const wxString &prefix)
+    = 0;
   /**
    * Called from GORank when a user presses the key
    * @param velocity the velocity value of the midi event
