@@ -29,7 +29,7 @@ unsigned GOStop::IsAuto() const {
   return (m_RankInfo.size() == 1 && m_RankInfo[0].Rank->GetPipeCount() == 1);
 }
 
-void GOStop::Load(GOConfigReader &cfg, wxString group) {
+void GOStop::Load(GOConfigReader &cfg, const wxString &group) {
   unsigned number_of_ranks = cfg.ReadInteger(
     ODFSetting, group, wxT("NumberOfRanks"), 0, 999, false, 0);
 
@@ -126,11 +126,11 @@ void GOStop::SetKey(unsigned note, unsigned velocity) {
   if (m_KeyVelocity[note] == velocity)
     return;
   m_KeyVelocity[note] = velocity;
-  if (IsActive())
+  if (IsEngaged())
     SetRankKey(note, m_KeyVelocity[note]);
 }
 
-void GOStop::ChangeState(bool on) {
+void GOStop::OnDrawstopStateChanged(bool on) {
   if (IsAuto()) {
     SetRankKey(0, on ? 0x7f : 0x00);
   } else {
@@ -143,7 +143,7 @@ GOStop::~GOStop(void) {}
 
 void GOStop::AbortPlayback() {
   if (IsAuto())
-    Set(false);
+    SetButtonState(false);
   GOButtonControl::AbortPlayback();
 }
 
@@ -157,7 +157,7 @@ void GOStop::PreparePlayback() {
 void GOStop::StartPlayback() {
   GODrawstop::StartPlayback();
 
-  if (IsAuto() && IsActive())
+  if (IsAuto() && IsEngaged())
     SetRankKey(0, 0x7f);
 }
 
