@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2024 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -32,16 +32,16 @@ private:
   unsigned m_NumberOfAccessiblePipes;
 
   void SetRankKey(unsigned key, unsigned velocity);
-  void ChangeState(bool on);
+  void OnDrawstopStateChanged(bool on) override;
 
-  void AbortPlayback();
-  void PreparePlayback();
-  void StartPlayback();
+  void AbortPlayback() override;
+  void PreparePlayback() override;
+  void StartPlayback() override;
 
 public:
   GOStop(GOOrganModel &organModel, unsigned first_midi_note_number);
   GORank *GetRank(unsigned index);
-  void Load(GOConfigReader &cfg, wxString group);
+  void Load(GOConfigReader &cfg, const wxString &group);
   void SetKey(unsigned note, unsigned velocity);
   ~GOStop(void);
 
