@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2024 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -19,7 +19,7 @@ class GOSwitch : public GODrawstop {
   unsigned m_IndexInManual = 0;
 
 protected:
-  void ChangeState(bool) override {}
+  void OnDrawstopStateChanged(bool) override {}
 
 public:
   GOSwitch(GOOrganModel &organModel) : GODrawstop(organModel) {}
