@@ -91,7 +91,7 @@ void GOTremulant::InitSoundProvider(GOMemoryPool &pool) {
   }
 }
 
-void GOTremulant::ChangeState(bool on) {
+void GOTremulant::OnDrawstopStateChanged(bool on) {
   if (m_TremulantType == GOSynthTrem) {
     GOSoundEngine *pSoundEngine = GetSoundEngine();
 
@@ -100,9 +100,7 @@ void GOTremulant::ChangeState(bool on) {
       m_PlaybackHandle = pSoundEngine ? pSoundEngine->StartTremulantSample(
                            m_TremProvider, m_TremulantN, m_LastStop)
                                       : nullptr;
-      on = (m_PlaybackHandle != nullptr);
-    } else {
-      assert(m_PlaybackHandle);
+    } else if (m_PlaybackHandle) {
       m_LastStop = pSoundEngine
         ? pSoundEngine->StopSample(m_TremProvider, m_PlaybackHandle)
         : 0;
@@ -123,7 +121,7 @@ void GOTremulant::AbortPlayback() {
 void GOTremulant::StartPlayback() {
   GODrawstop::StartPlayback();
 
-  if (IsActive() && m_TremulantType == GOSynthTrem) {
+  if (IsEngaged() && m_TremulantType == GOSynthTrem) {
     GOSoundEngine *pSoundEngine = GetSoundEngine();
 
     assert(m_TremulantN > 0);
