@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -13,19 +13,18 @@
 #include <vector>
 
 #include "pipe-config/GOPipeConfigTreeNode.h"
-
-#include "GOPlaybackStateHandler.h"
+#include "sound/GOSoundStateHandler.h"
 
 class GOConfigReader;
 class GOEnclosure;
 class GOPipeWindchestCallback;
 class GORank;
 class GOTremulant;
-class GOOrganController;
+class GOOrganModel;
 
-class GOWindchest : private GOPlaybackStateHandler {
+class GOWindchest : private GOSoundStateHandler {
 private:
-  GOOrganController *m_OrganController;
+  GOOrganModel &r_OrganModel;
   wxString m_Name;
   float m_Volume;
   std::vector<GOEnclosure *> m_enclosure;
@@ -34,13 +33,10 @@ private:
   std::vector<GOPipeWindchestCallback *> m_pipes;
   GOPipeConfigTreeNode m_PipeConfig;
 
-  void AbortPlayback();
-  void StartPlayback();
   void PreparePlayback();
-  void PrepareRecording();
 
 public:
-  GOWindchest(GOOrganController *organController);
+  GOWindchest(GOOrganModel &organModel);
 
   void Init(GOConfigReader &cfg, wxString group, wxString name);
   void Load(GOConfigReader &cfg, wxString group, unsigned index);
