@@ -8,8 +8,8 @@
 #ifndef GOPIPECONFIG_H
 #define GOPIPECONFIG_H
 
+#include <algorithm>
 #include <cstdint>
-
 #include <wx/string.h>
 
 #include "GOBool3.h"
@@ -40,6 +40,7 @@ private:
   uint16_t m_DefaultDelay;
   uint16_t m_Delay;
   uint16_t m_ReleaseTail; // the max release length in ms
+  int8_t m_ToneBalanceValue;
   int8_t m_BitsPerSample;
   int8_t m_Channels;
   int8_t m_LoopLoad;
@@ -128,6 +129,9 @@ public:
     SetPitchMember(cents, m_AutoTuningCorrection);
   }
 
+  int8_t GetToneBalanceValue() const { return m_ToneBalanceValue; }
+  void SetToneBalanceValue(int8_t value);
+
   uint16_t GetDefaultDelay() const { return m_DefaultDelay; }
   uint16_t GetDelay() const { return m_Delay; }
   void SetDelay(uint16_t delay) { SetSmallMember(delay, m_Delay); }
