@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2024 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -25,7 +25,6 @@ private:
     PaStreamCallbackFlags statusFlags,
     void *userData);
 
-  static wxString getName(const PaDeviceInfo *pInfo);
   static wxString getLastError(PaError error);
 
 public:
@@ -43,8 +42,11 @@ public:
   static const std::vector<wxString> &getApis() {
     return GOSoundPortFactory::c_NoApis;
   }
+
   static GOSoundPort *create(
-    const GOPortsConfig &portsConfig, GOSound *sound, const wxString &name);
+    const GOPortsConfig &portsConfig,
+    GOSound *sound,
+    GODeviceNamePattern &pattern);
   static void addDevices(
     const GOPortsConfig &portsConfig, std::vector<GOSoundDevInfo> &list);
   static void terminate();
