@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2024 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -12,12 +12,12 @@
 
 #include "threading/GOMutex.h"
 
-class GOSoundWorkItem;
+class GOSoundTask;
 
 class GOSoundScheduler {
 private:
-  std::vector<GOSoundWorkItem *> m_Work;
-  std::vector<GOSoundWorkItem **> m_WorkItems;
+  std::vector<GOSoundTask *> m_Work;
+  std::vector<GOSoundTask **> m_Tasks;
   // if GetNextGroup() always returns nullptr
   std::atomic_bool m_IsNotGivingWork;
   std::atomic_uint m_NextItem;
@@ -26,15 +26,15 @@ private:
   GOMutex m_Mutex;
 
   void Lock() { m_ItemCount.store(0); }
-  void Unlock() { m_ItemCount.store(m_WorkItems.size()); }
+  void Unlock() { m_ItemCount.store(m_Tasks.size()); }
   void Update();
 
-  bool CompareItem(GOSoundWorkItem *a, GOSoundWorkItem *b);
-  void SortList(std::vector<GOSoundWorkItem *> &list);
-  void ResetList(std::vector<GOSoundWorkItem *> &list);
-  void AddList(GOSoundWorkItem *item, std::vector<GOSoundWorkItem *> &list);
-  void RemoveList(GOSoundWorkItem *item, std::vector<GOSoundWorkItem *> &list);
-  void ExecList(std::vector<GOSoundWorkItem *> &list);
+  bool CompareItem(GOSoundTask *a, GOSoundTask *b);
+  void SortList(std::vector<GOSoundTask *> &list);
+  void ResetList(std::vector<GOSoundTask *> &list);
+  void AddList(GOSoundTask *item, std::vector<GOSoundTask *> &list);
+  void RemoveList(GOSoundTask *item, std::vector<GOSoundTask *> &list);
+  void ExecList(std::vector<GOSoundTask *> &list);
 
 public:
   GOSoundScheduler();
@@ -45,13 +45,13 @@ public:
   void Clear();
   void Reset();
   void Exec();
-  void Add(GOSoundWorkItem *item);
-  void Remove(GOSoundWorkItem *item);
+  void Add(GOSoundTask *item);
+  void Remove(GOSoundTask *item);
 
   void PauseGivingWork() { m_IsNotGivingWork.store(true); }
   void ResumeGivingWork() { m_IsNotGivingWork.store(false); }
 
-  GOSoundWorkItem *GetNextGroup();
+  GOSoundTask *GetNextGroup();
 };
 
 #endif
